Annotation Type Index


  • @Retention(CLASS)
    @Target(FIELD)
    public @interface Index
    Specifies that the property should be indexed.

    It is highly recommended to index properties that are used in a query to improve query performance.

    To fine tune indexing of a property you can override the default index type().

    Note: indexes are currently not supported for byte array, float or double properties.